@@ -422,7 +422,10 @@ Desktop::Desktop(const AppID& appid,
            stringFromKeyfileWithFallback<Application::Info::Splash::Color>(keyfile, "X-Lomiri-Splash-Color", "X-Ubuntu-Splash-Color"),
            stringFromKeyfileWithFallback<Application::Info::Splash::Color>(keyfile, "X-Lomiri-Splash-Color-Header", "X-Ubuntu-Splash-Color-Header"),
            stringFromKeyfileWithFallback<Application::Info::Splash::Color>(keyfile, "X-Lomiri-Splash-Color-Footer", "X-Ubuntu-Splash-Color-Footer"),
-           boolFromKeyfileWithFallback<Application::Info::Splash::ShowHeader>(keyfile, "X-Lomiri-Splash-Show-Header", "X-Ubuntu-Splash-Show-Header", false)})
+           boolFromKeyfileWithFallback<Application::Info::Splash::ShowHeader>(keyfile, "X-Lomiri-Splash-Show-Header", "X-Ubuntu-Splash-Show-Header", false),
+           // This can either be X-Ubuntu-Splash-Show or No Display, but will always prefer X-Ubuntu-Splash-Show
+           boolFromKeyfileWithFallback<Application::Info::Splash::Show>(keyfile, "X-Lomiri-Splash-Show", "X-Ubuntu-Splash-Show",
+                                       !boolFromKeyfile<NoDisplay>(keyfile, "NoDisplay", false).value())})
     , _supportedOrientations([keyfile]() {
         Orientations all = {true, true, true, true};
 
