@@ -21,6 +21,8 @@
 
 #include <list>
 
+#include "config.h"
+
 #include "helper.h"
 #include "jobs-base.h"
 
@@ -74,7 +76,10 @@ public:
     std::vector<std::shared_ptr<Helper::Instance>> instances() override;
 
     std::shared_ptr<Helper::Instance> launch(std::vector<Helper::URL> urls = {}) override;
+#ifdef LAL_USE_MIRCLIENT
     std::shared_ptr<Helper::Instance> launch(MirPromptSession* session, std::vector<Helper::URL> urls = {}) override;
+#endif
+
 
     std::shared_ptr<Helper::Instance> existingInstance(const std::string& instanceid);
 
