@@ -23,10 +23,7 @@
 #include "second-exec-core.h"
 #include "string-util.h"
 #include "utils.h"
-
-extern "C" {
 #include "lomiri-app-launch-trace.h"
-}
 
 #include <gio/gio.h>
 #include <sys/types.h>
@@ -176,7 +173,7 @@ std::shared_ptr<Application::Instance> POSIX::launch(
         std::string appIdStr{appId};
         g_debug("Initializing params for an new instance::POSIX for: %s", appIdStr.c_str());
 
-        tracepoint(lomiri_app_launch, libual_start, appIdStr.c_str());
+        tracepoint(lomiri_app_launch, liblal_start, appIdStr.c_str());
 
         int timeout = 1;
         if (lomiri::app_launch::Registry::Impl::isWatchingAppStarting())
@@ -282,7 +279,7 @@ std::shared_ptr<Application::Instance> POSIX::launch(
         for (const auto& rmenv :
              {"APP_DIR", "APP_URIS", "APP_EXEC", "APP_EXEC_POLICY", "APP_LAUNCHER_PID",
               "INSTANCE_ID", "MIR_SERVER_PLATFORM_PATH", "MIR_SERVER_PROMPT_FILE", "MIR_SERVER_HOST_SOCKET",
-              "UBUNTU_APP_LAUNCH_OOM_HELPER", "UBUNTU_APP_LAUNCH_LEGACY_ROOT"})
+              "LOMIRI_APP_LAUNCH_OOM_HELPER", "LOMIRI_APP_LAUNCH_LEGACY_ROOT"})
         {
             removeEnv(rmenv, env);
         }
@@ -348,7 +345,7 @@ std::shared_ptr<Application::Instance> POSIX::launch(
         g_debug("child_pid: %d", child_pid);
         launchedpids.emplace_back(child_pid);
 
-        tracepoint(lomiri_app_launch, libual_start_message_sent, appIdStr.c_str());
+        tracepoint(lomiri_app_launch, liblal_start_message_sent, appIdStr.c_str());
 
         return retval;
     });
@@ -504,9 +501,10 @@ std::vector<std::string> POSIX::parseExec(std::list<std::pair<std::string, std::
     auto appexecpolicy = findEnv("APP_EXEC_POLICY", env);
     if (!appexecpolicy.empty() && appexecpolicy != "unconfined")
     {
+        retval.emplace(retval.begin(), "--");
         retval.emplace(retval.begin(), appexecpolicy);
         retval.emplace(retval.begin(), "-p");
-        retval.emplace(retval.begin(), "aa-exec");
+        retval.emplace(retval.begin(), AA_EXEC_PATH);
     }
 
     return retval;
