@@ -794,6 +794,21 @@ std::shared_ptr<Application::Instance> SystemD::launch(
         g_variant_builder_close(&builder);
         g_variant_builder_close(&builder);
 
+        if (isApplication) {
+            /*
+             * Conflicts - we do this to make sure apps will stop when Lomiri/
+             * display server dies, even if the application is SIGSTOP'ed.
+             */
+            g_variant_builder_open(&builder, G_VARIANT_TYPE_TUPLE);
+            g_variant_builder_add_value(&builder, g_variant_new_string("Conflicts"));
+            g_variant_builder_open(&builder, G_VARIANT_TYPE_VARIANT);
+            g_variant_builder_open(&builder, G_VARIANT_TYPE_ARRAY);
+            g_variant_builder_add_value(&builder, g_variant_new_string("lal-application-end.target"));
+            g_variant_builder_close(&builder);
+            g_variant_builder_close(&builder);
+            g_variant_builder_close(&builder);
+        }
+
         /* Parameter Array */
         g_variant_builder_close(&builder);
 
