@@ -709,6 +709,7 @@ lomiri_app_launch_start_multiple_helper (const gchar * type, const gchar * appid
 	}
 }
 
+#ifdef LAL_USE_MIRCLIENT
 gchar *
 lomiri_app_launch_start_session_helper (const gchar * type, MirPromptSession * session, const gchar * appid, const gchar * const * uris)
 {
@@ -735,6 +736,7 @@ lomiri_app_launch_start_session_helper (const gchar * type, MirPromptSession * s
 		return nullptr;
 	}
 }
+#endif
 
 gboolean
 lomiri_app_launch_stop_helper (const gchar * type, const gchar * appid)
