@@ -18,7 +18,12 @@
  */
 
 #include <glib.h>
+
+#include "config.h"
+
+#ifdef LAL_USE_MIRCLIENT
 #include <mir_toolkit/mir_prompt_session.h>
+#endif
 
 #ifndef __LOMIRI_APP_LAUNCH_H__
 #define __LOMIRI_APP_LAUNCH_H__ 1
@@ -480,6 +485,7 @@ gchar *    lomiri_app_launch_start_multiple_helper     (const gchar *
                                                          const gchar *                     appid,
                                                          const gchar * const *             uris);
 
+#ifdef LAL_USE_MIRCLIENT
 /**
  * lomiri_app_launch_start_session_helper:
  * @type: Type of helper
@@ -502,6 +508,7 @@ gchar *    lomiri_app_launch_start_session_helper  (const gchar *            typ
                                                     MirPromptSession *       session,
                                                     const gchar *            appid,
                                                     const gchar * const *    uris);
+#endif
 
 /**
  * lomiri_app_launch_stop_helper:
