@@ -201,6 +201,7 @@ TEST_F(ApplicationInfoDesktop, UbuntuFallback)
     EXPECT_EQ("green", fallbackAppinfo.splash().headerColor.value());
     EXPECT_EQ("blue", fallbackAppinfo.splash().footerColor.value());
     EXPECT_TRUE(fallbackAppinfo.splash().showHeader.value());
+    EXPECT_TRUE(fallbackAppinfo.splash().show.value());
     EXPECT_EQ(fallbackOrientations, fallbackAppinfo.supportedOrientations());
     EXPECT_TRUE(fallbackAppinfo.rotatesWindowContents().value());
     EXPECT_TRUE(fallbackAppinfo.supportsLomiriLifecycle().value());
@@ -214,6 +215,7 @@ TEST_F(ApplicationInfoDesktop, UbuntuFallback)
     g_key_file_set_string(keyfile.get(), DESKTOP, "X-Lomiri-Splash-Color-Header", "cyan");
     g_key_file_set_string(keyfile.get(), DESKTOP, "X-Lomiri-Splash-Color-Footer", "magenta");
     g_key_file_set_boolean(keyfile.get(), DESKTOP, "X-Lomiri-Splash-Show-Header", false);
+    g_key_file_set_boolean(keyfile.get(), DESKTOP, "X-Lomiri-Splash-Show", false);
     g_key_file_set_string(keyfile.get(), DESKTOP, "X-Lomiri-Supported-Orientations", "landscape;");
     g_key_file_set_boolean(keyfile.get(), DESKTOP, "X-Lomiri-Rotates-Window-Contents", false);
     g_key_file_set_boolean(keyfile.get(), DESKTOP, "X-Lomiri-Touch", false);
@@ -228,12 +230,44 @@ TEST_F(ApplicationInfoDesktop, UbuntuFallback)
     EXPECT_EQ("cyan", lomiriAppinfo.splash().headerColor.value());
     EXPECT_EQ("magenta", lomiriAppinfo.splash().footerColor.value());
     EXPECT_FALSE(lomiriAppinfo.splash().showHeader.value());
+    EXPECT_FALSE(lomiriAppinfo.splash().show.value());
     EXPECT_EQ(lomiriOrientations, lomiriAppinfo.supportedOrientations());
     EXPECT_FALSE(lomiriAppinfo.rotatesWindowContents().value());
     EXPECT_FALSE(lomiriAppinfo.supportsLomiriLifecycle().value());
     EXPECT_FALSE(lomiriAppinfo.singleInstance().value());
 }
 
+TEST_F(ApplicationInfoDesktop, ShowSplashOverride)
+{
+    auto keyfile = defaultKeyfile();
+
+    auto lomiriAppinfo = lomiri::app_launch::app_info::Desktop(simpleAppID(), keyfile, "/", {},
+                                                                lomiri::app_launch::app_info::DesktopFlags::ALLOW_NO_DISPLAY, nullptr);
+    EXPECT_TRUE(lomiriAppinfo.splash().show.value());
+
+    g_key_file_set_boolean(keyfile.get(), DESKTOP, "NoDisplay", true);
+    lomiriAppinfo = lomiri::app_launch::app_info::Desktop(simpleAppID(), keyfile, "/", {},
+                                                                lomiri::app_launch::app_info::DesktopFlags::ALLOW_NO_DISPLAY, nullptr);
+    EXPECT_FALSE(lomiriAppinfo.splash().show.value());
+
+    // Should override
+    g_key_file_set_boolean(keyfile.get(), DESKTOP, "X-Lomiri-Splash-Show", true);
+    lomiriAppinfo = lomiri::app_launch::app_info::Desktop(simpleAppID(), keyfile, "/", {},
+                                                                lomiri::app_launch::app_info::DesktopFlags::ALLOW_NO_DISPLAY, nullptr);
+    EXPECT_TRUE(lomiriAppinfo.splash().show.value());
+    g_key_file_set_boolean(keyfile.get(), DESKTOP, "X-Lomiri-Splash-Show", false);
+    lomiriAppinfo = lomiri::app_launch::app_info::Desktop(simpleAppID(), keyfile, "/", {},
+                                                                lomiri::app_launch::app_info::DesktopFlags::ALLOW_NO_DISPLAY, nullptr);
+    EXPECT_FALSE(lomiriAppinfo.splash().show.value());
+
+    // X-Lomiri should still override NoDisplay
+    g_key_file_set_boolean(keyfile.get(), DESKTOP, "NoDisplay", false);
+    lomiriAppinfo = lomiri::app_launch::app_info::Desktop(simpleAppID(), keyfile, "/", {},
+                                                                lomiri::app_launch::app_info::DesktopFlags::ALLOW_NO_DISPLAY, nullptr);
+    EXPECT_FALSE(lomiriAppinfo.splash().show.value());
+}
+
+
 TEST_F(ApplicationInfoDesktop, KeyfileIconPatterns)
 {
     auto defkeyfile = defaultKeyfile();
